@@ -735,7 +735,7 @@ class provider_MutluSMS_tu(provider):
 		    return False, 'Failed. Provider responded: %s' %(ERROR_MSG[result.strip("HATA:")])
 		MainWindow.Stat.close()
 
-# VoipBusterPro 1.0
+# VoipBusterPro 1.1
 # API Docs: http://www.voipbusterpro.com/en/sms_instructions.html
 # VoipBusterPro Provider written by Bjoern Olausson <maemo@olausson.de>
 class provider_VoipBusterPro(provider):
@@ -810,14 +810,14 @@ class provider_VoipBusterPro(provider):
 		except HTTPError, e:
 			return False, 'Error %s returned from service\n\n %s' %(e.code, result)
 		UpdatePbar(self, MainWindow, app, "2", "Checking reply")
-		re_suc = re.compile('OK')
+		re_suc = re.compile('success', flags=re.IGNORECASE)
 		if re_suc.search(result):
-		    return True, '%s' %(result)
+		     return True, 'Success. SMS was send' %(result)
 		else:
 		    return False, 'Failed. Provider responded: %s' %(result)
 		MainWindow.Stat.close()
 
-# Telbo 1.0
+# Telbo 1.1
 # API Docs: http://www.telbo.com/en/sms_instructions.html
 # Telbo Provider written by Bjoern Olausson <maemo@olausson.de>
 class provider_Telbo(provider):
@@ -892,9 +892,9 @@ class provider_Telbo(provider):
 		except HTTPError, e:
 			return False, 'Error %s returned from service\n\n %s' %(e.code, result)
 		UpdatePbar(self, MainWindow, app, "2", "Checking reply")
-		re_suc = re.compile('OK')
+		re_suc = re.compile('success', flags=re.IGNORECASE)
 		if re_suc.search(result):
-		    return True, '%s' %(result)
+		    return True, 'Success. SMS was send' %(result)
 		else:
 		    return False, 'Failed. Provider responded: %s' %(result)
 		MainWindow.Stat.close()
\ No newline at end of file
